@@ -30,7 +30,9 @@ use Clustericious::RouteBuilder::Common;
 use Clustericious::Config;
 use Clustericious::Commands;
 
-
+sub _have_rose {
+    return 1 if Rose::Planter->can("tables");
+}
 
 has commands => sub {
   my $commands = Clustericious::Commands->new(app => shift);
@@ -172,14 +174,14 @@ sub dump_api {
         $pat->_compile;
         my %placeholders = map { $_ => "<$_>" } @{ $pat->placeholders };
         my $method = uc join ',', @{ $r->via || ["GET"] };
-        if ($placeholders{table}) {
+        if (_have_rose() && $placeholders{table}) {
             for my $table (Rose::Planter->tables) {
                 $placeholders{table} = $table;
                 my $pat = $pat->pattern;
                 $pat =~ s/:table/$table/;
                 push @all, "$method $pat";
             }
-        } elsif ($placeholders{items}) {
+        } elsif (_have_rose() && $placeholders{items}) {
             for my $plural (Rose::Planter->plurals) {
                 $placeholders{items} = $plural;
                 my $line = $pat->render(\%placeholders);
@@ -218,7 +220,8 @@ sub _dump_api_table_types
 sub dump_api_table
 {
     my($self, $table) = @_;
-    my $class = eval { Rose::Planter->find_class($table) };
+    return unless _have_rose();
+    my $class = Rose::Planter->find_class($table);
     return unless defined $class;
 
     return {
