@@ -1,18 +1,53 @@
-package Clustericious::Command::stop;
+=head1 NAME
 
-use strict;
-use warnings;
+Clustericious::Command::stop
+
+=head1 DESCRIPTION
+
+Stop a running daemon.
+
+=head1 NOTES
+
+The different methods of starting put their pid files in
+different places in the config file.   Here are some
+examples :
+
+   "hypnotoad" : {
+      "pid_file"  : "/tmp/filename.pid",
+      ....
+    }
+
+   "plackup" : {
+      "pidfile"   : "/tmp/nother_filename.pid",
+      "daemonize" : "null"    # means include "--daemonize"
+   ...
+   },
+
+   "lighttpd" : {
+      "env" : {
+          "lighttpd_pid"    : "/tmp/third_filename.pid"
+           ...
+      },
+   },
+
+   "nginx" : {
+     '-p' : '/home/foo/appname/nginx'
+    }
+
+=cut
+
+package Clustericious::Command::stop;
 use Clustericious::Log;
 use Clustericious::App;
 use Mojo::URL;
 use File::Basename qw/dirname/;
-use base 'Clustericious::Command';
+
+use base 'Mojolicious::Command';
 use Clustericious::Config;
 use File::Slurp qw/slurp/;
 
-# ABSTRACT: Clustericious command to stop a Clustericious application
-our $VERSION = '0.9940_04'; # VERSION
-
+use strict;
+use warnings;
 
 __PACKAGE__->attr(description => <<EOT);
 Stop a running daemon.
@@ -89,7 +124,6 @@ sub _stop_apache {
 
 sub run {
     my $self     = shift;
-    exit 2 unless $self->app->sanity_check;
     my $conf     = Clustericious::Config->new( $ENV{MOJO_APP} );
 
     Clustericious::App->init_logging();
@@ -110,70 +144,3 @@ sub run {
 
 1;
 
-
-__END__
-=pod
-
-=head1 NAME
-
-Clustericious::Command::stop - Clustericious command to stop a Clustericious application
-
-=head1 VERSION
-
-version 0.9940_04
-
-=head1 SYNOPSIS
-
- % yourapp stop
-
-=head1 DESCRIPTION
-
-Stop a running daemon.
-
-=head1 NOTES
-
-The different methods of starting put their pid files in
-different places in the config file.   Here are some
-examples :
-
-   "hypnotoad" : {
-      "pid_file"  : "/tmp/filename.pid",
-      ....
-    }
-
-   "plackup" : {
-      "pidfile"   : "/tmp/nother_filename.pid",
-      "daemonize" : "null"    # means include "--daemonize"
-   ...
-   },
-
-   "lighttpd" : {
-      "env" : {
-          "lighttpd_pid"    : "/tmp/third_filename.pid"
-           ...
-      },
-   },
-
-   "nginx" : {
-     '-p' : '/home/foo/appname/nginx'
-    }
-
-=head1 AUTHOR
-
-original author: Brian Duggan
-
-current maintainer: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Curt Tilmes
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by NASA GSFC.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
